summaryrefslogtreecommitdiff
path: root/src/charon/plugins/nm/nm_creds.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/charon/plugins/nm/nm_creds.h')
-rw-r--r--src/charon/plugins/nm/nm_creds.h15
1 files changed, 11 insertions, 4 deletions
diff --git a/src/charon/plugins/nm/nm_creds.h b/src/charon/plugins/nm/nm_creds.h
index 421442c81..b55cff31e 100644
--- a/src/charon/plugins/nm/nm_creds.h
+++ b/src/charon/plugins/nm/nm_creds.h
@@ -35,14 +35,21 @@ struct nm_creds_t {
* Implements credential_set_t
*/
credential_set_t set;
-
+
/**
* Set the trusted gateway certificate to serve by this set.
*
* @param cert certificate to serve
*/
- void (*set_certificate)(nm_creds_t *this, certificate_t *cert);
-
+ void (*add_certificate)(nm_creds_t *this, certificate_t *cert);
+
+ /**
+ * Load CA certificates recursively from a directory.
+ *
+ * @param dir directory to PEM encoded CA certificates
+ */
+ void (*load_ca_dir)(nm_creds_t *this, char *dir);
+
/**
* Set the username/password for authentication.
*
@@ -35,14 +35,21 @@ struct nm_creds_t {
/**
- * Set the trusted gateway certificate to serve by this set.
+ * Add a trusted gateway certificate to serve by this set.
*
* @param cert certificate to serve